#ifdef	__cplusplus
extern "C" {
#endif

/*
 *  function realloc with error checking
 */
void *myrealloc(void *ptr, size_t size);

/*
 *  function malloc with error checking
 */
void *mymalloc(size_t size);

/*
 *  Read sequence from file f with FASTA format and store it in seq.
 *  Alloc enough memory to store the sequence.
 *  Returns the size of the sequence or 0 on error. 
 */
int readsequence(FILE *file, char**seq, char **name);

/*
 *  Dynamically allocate a matrix of integers with n rows and m columns
 */
int	**allocmatrix( int n, int m);

/*
 *  Deallocate a matrix of integers with n rows and m columns
 */
void	freematrix( int **mat );


/*
 * Returns in Seq a random DNA sequence of length Len 
 */

char *RandomSeq(char *Seq, int Len);
void SeedRandomSeq(unsigned int Seed);

/*
 * Returns in RevComp a the reverse complementation of Sequence Seq of length Len
 */
char *ReverseComplement(char *RevComp, char *Seq, int Len);


/*
 * Print Alignment of two sequences.
 *    Sequence of name name1 starts in position from1 and finishes in position to1.
 *    Sequence of name name2 starts in position from2 and finishes in position to2.
 *    The alignment is given by two rows align1 and align2 of length len and
 *       score is its punctuation.  Gaps are represented by ' ' or '-'.
 *    At most, maxcols columns of alignment per line are printed.  It defaults
 *       to 60, if maxcols <= 0.
 */
void PrintAlignment( char *name1, int from1, int to1, char *align1,
		     char *name2, int from2, int to2, char *align2,
		     int len, int score, int maxcols);

#ifdef	__cplusplus
}
#endif

  
